Core Functions
==============

These are the core analysis functions that form the foundation of edaflow's EDA capabilities.

.. currentmodule:: edaflow

Data Quality Analysis
---------------------

.. autofunction:: check_null_columns

.. autofunction:: analyze_categorical_columns

.. autofunction:: convert_to_numeric

.. autofunction:: display_column_types

Data Imputation
---------------

.. autofunction:: impute_numerical_median

.. autofunction:: impute_categorical_mode

Outlier Handling
----------------

.. autofunction:: handle_outliers_median

EDA Insights & Summary
----------------------

.. autofunction:: summarize_eda_insights

Helper Functions
----------------

.. autofunction:: hello
